#	-------------------------------S A M P L E   P R O G R A M   C O D E   R ---------------------------------------------------

#	Note: The sample program code serves as an orientation for writing your program code. The objective is to 
#   generate an output file that is helping the output check for confidentiality in the best possible way. 
#   Please note: This sample program code does not provide statistic-specific support on the processing and 
#   analysis of your requested data.

#	In advance, here are some basic aspects for your work with Stata in the RDC context:

#   - Please delete temporary and/or working datasets that you do not need anymore at the end of your program codes.					

#   - Please write a master program (part 1 of the sample program code) and separate programs for your 
#     analyses (part 2 of the sample program code), both in accordance wit the sample program codes. 

#   - Please define your work environment (e.g. safe centre, remote execution) in the master program
#     and introduce your (possibly various) datasets.
  
#	- Please consider the "Basic requirements concerning the program code" and the "List of criteria on the admission
#	  of output" that you find in the brochure "Regulations on the analysis of microdata".

#	Please also note that the online access to R-packages is not possible via the RDC. Please provide us with a version
#	of the R-package that we can save locally if you want to use one. R-Packages are only allowed after they were
#	checked by the RDC staff.


#	-------------------------------------------------------------------------------------------------------------------
#   ----
#	----	Basic settings
#	----
#	-------------------------------------------------------------------------------------------------------------------

# Empty memory

rm(list=ls()) 

# further basic settings, if needed 



#	-------------------------------------------------------------------------------------------------------------------
#	----
#	----	Part I: Define work environment
#   ----
#	-------------------------------------------------------------------------------------------------------------------

# At the RDC, we generally differ between three work environments:
#   0. personal work environment at the office/at home
#   1. remote execution
#   2. safe centre

# There are RDC products that only run in one work environment, e.g. pure safe centre projects.
# However, there are also RDC projects that run in several work environments. There are, for example, datasets that 
# can't be provided in full at the safe centre (economic data, tax data). Users have only limited access to the 
# data at the safe centre but they can use it to write program codes. Those are then applied to the original data by 
# the RDC staff. This makes an adaptation of the path specification necessary.

# To make those basic settings clear, we kindly ask you to define your work environment and to put in the according
# paths.

# Please differ between the following three work environments and adjust the paths for all relevant work environments.
# Please delete paths that are not needed and add missing ones.

# 0: personal workspace (e.g. data structure file)
# 1: remote execution (original dataset)
# 2: safe centre (pseudonymised original data, possibly without Bavaria)

# Define work environment (see above)

RDC=1 


# 	Note on the definition on the work environment:
# 	Please do not change the names of the globals for the definition of the destination folder. Should you need 
# 	several destination folders for one type of results, please name them according to the following pattern: 
# 	global outputpfad-1, global outputpfad-2, ...


#	Work environment 0: Path specification for working at the personal workplace (e.g. data structure file)
#	-------------------------------------------------------------------------------------------------------------------

if (RDC==0)  {
  datenpfad    <- "<personal workspace: data>" # contains, for example, the data structure file
  syntaxpfad   <- "<personal workspace: program>" # all program codes are to be saved here
  outputpfad   <- "<personal workspace: results>" # all results (incl. log files) are to be saved here
  neudatenpfad <- "<personal workspace: work files>" # all newly created datasets are to be saved here

  dateiname    <- "insert name of dataset" # e.g. name of the data structure file
  outputname   <- "insert name of log file" # insert name of the log file
  syntaxname   <- "insert name of program code" # insert name of the program code that is to be startet from the master program
  
  .libPaths("<personal workspace: R-packages>") # locally save all necessary R-packages here
}

#	Work environment 1: Path specifications for working via remote execution (note: you are given all relevant paths via e-mail at the begin of your project)
#	-------------------------------------------------------------------------------------------------------------------

if (RDC==1) {
  datenpfad    <- "Q:/Projektxxxx/Daten" # contains the original data	   
  syntaxpfad   <- "Q:/Projektxxxx/xxx" # all program codes are to be saved here
  outputpfad   <- "Q:/Projektxxxx/xxx" # all results (incl. log files) are to be saved here
  neudatenpfad <- "Q:/Projektxxxx/xxx" # all newly created datasets are to be saved here
  
  dateiname    <- "insert name of dataset" # e.g. name of the data structure file
  outputname   <- "insert name of log file" # insert name of the log file
  syntaxname   <- "insert name of program code" # insert name of the program code that is to be startet from the master program
  
  .libPaths("Q:/stata/ado") # all R-packages are saved here
}

#	Work environment 2: Path specifications for working at the safe centre(_formal)
#	-------------------------------------------------------------------------------------------------------------------

if (RDC==2) {
  datenpfad    <- "R:/Projektxxxx/Daten" # contains the original data	   
  syntaxpfad   <- "R:/Projektxxxx/xxx" # all program codes are to be saved here
  outputpfad   <- "R:/Projektxxxx/xxx" # all results (incl. log files) are to be saved here
  neudatenpfad <- "R:/Projektxxxx/xxx" # all newly created datasets are to be saved here
  
  dateiname    <- "insert name of dataset" # e.g. name of the data structure file
  outputname   <- "insert name of log file" # insert name of the log file
  syntaxname   <- "insert name of program code" # insert name of the program code that is to be startet from the master program
  
  .libPaths("R:/stata/ado") # all R-packages are saved here
}


# -------------------------------------------------------------------------------------------------------------------###
# Calling the analyses program code and starting the log
# -------------------------------------------------------------------------------------------------------------------

sink(paste(outputpfad, "/", logdatei, ".log", sep=""), type = c("output", "message"), split = TRUE)

source(paste(syntaxpfad, "/", syntaxname, ".R", sep=""), echo = TRUE, max.deparse.length = 99999)

sink()

#	-------------------------------------------------------------------------------------------------------------------
#	N O T E:

#	The sample program code at hand illustrates an example for an initial program code. If analyses are executed 
#	in subsequent program codes and these analyses have a content-related connection to already generated results, 
#	these connections are to be marked with a comment when processing the data and when the analysis is being
#	commanded.
#	-------------------------------------------------------------------------------------------------------------------
