# Insert timestamp
date()

#	-------------------------------------------------------------------------------------------------------------------
#	----
#	----	Part II: Processing of the data
#	----
#	-------------------------------------------------------------------------------------------------------------------

# -------------------------------------------------------------------------------------------------------------------

#	Project title:			<Women and employment in Germany>       
#	Data base:		 		<Example Microcensus 2012>
	
#	Name of program code:	<syntax_name.do> // if applicable, please also state the version of the program code
#	created: 				<Date> 
#	by: 					<Name> 
#	E-mail: 				<E-mail address> 
#	Phone: 					<phone number> 
	
#	Name of output file: 	<output_name.log>
	
	
#	Outline of the program: 
#				<Program code for the examination of multiple person data sets (Check of the data base), 
#				 descriptive analyses> 
	 
	
#	Used variables (example dataset here: microcensus 2012): 
#	Original variables: 
#	   <EF1:   		Federal state 
#	 	EF2:   		Administrative district 
#	 	EF3:  		Number of selected district 
#	 	EF4:  		Serial number of household in selected district 
#	 	EF5:  		Serial number of person in the household
#	 	EF25:  		Serial number of familiy in the household
#	 	EF30:  		Population at primary residence
#	 	EF31:  		Population in private households
#	 	EF44:  		Age
#	 	EF46:  		Sex
#	 	EF49:  		Marital status
#	 	EF310: 		Highest school-leaving qualification
#	 	EF952: 		Standard projection factor year>
	
	 
#	Newly created variables in this program code <syntax_name.do>: 
#	   <marr:       dichotomous variable married yes/no
#		persnr:  	Number of person
#	 	famnr:   	Number of familiy 
#	 	hhnr:    	Number of household 
#	 	nrdiff:  	Difference number of household - number of family
#	 	piddiff: 	Test unique number of person>
	
#	Note: If you use variables that were created in a previous program code, please list them in a separate block. 
	
#	Variable projection factor: EF952


# -------------------------------------------------------------------------------------------------------------------
#	0. Load packages
#	-------------------------------------------------------------------------------------------------------------------

# Install packages 

# Safe centre: Please e-mail us all R-packages - including all dependencies - in a zip-folder

setwd("<R-packages are saved here>")
install.packages(pkgs=c("miceadds", "car", "Hmisc", "foreign", "pastecs", "tidyverse", "questionr", "knitr", "+ zip-folder with all dependencies"), type = "source", repos = NULL)


# Remote execution: 

install.packages(pkgs=c("miceadds", "car", "Hmisc", "foreign", "pastecs", "tidyverse", "questionr", "knitr" ,"Please add additional necessary packages"), dependencies=TRUE)

# Load packages that are to be used

library(miceadds)
library(car)
library(Hmisc)
library(pastecs)
library(foreign)
library(tidyverse)
library(questionr)
library(knitr)


# -------------------------------------------------------------------------------------------------------------------
#	1. Editing data
#	-------------------------------------------------------------------------------------------------------------------


#	a.  Input dataset
#	    Memory space- and runtime-efficient direct selection of necessary variables.

#	    Population in private households (EF31 = 1) at the place of permanent residence (EF30 < 3)

Daten <- subset(load.Rdata2(paste(dateiname, ".Rdata", sep=""), path=datenpfad), EF31 == 1 & EF30 < 3, select=c(EF1:EF5,EF25,EF30,EF31,EF44,EF46,EF49,EF310,EF952))

# Alternative using pipes

Daten <- load.Rdata2(paste0(dateiname, ".Rda"), path = datenpfad) %>%
  select(EF1:EF5,EF25,EF30,EF31,EF44,EF46,EF49,EF310,EF952) %>%
  filter(EF31 == 1 & EF30 < 3)

# Alternativly, csv-datasets can be loaded and variables that are not needed can be deleted separately:

Daten <- read.csv(file.path(datenpfad, paste(dateiname,  ".csv",  sep="")), header = T, sep=";")
Daten <- subset(Daten, select= -c(EF2:EF4, EF6:EF20))

# create temporary work dataset 

save(Daten, file=paste0(neudatenpfad,"Temp1.rdata")) 
# This dataset is no longer needed after the analysis and can be deleted at the end.
# Better than deletion: don't even save temporary datasets.


# b.  Generate dichotomous variable marr which shows if a person is married.  

Daten$marr <- 0
Daten$marr[Daten$EF49==2] <- 1 

# Alternative using pipes

Daten <- Daten %>%
  mutate(marr2 = ifelse(EF49 == 2, 1, 0))


# c.  Generate number of household and family from EF1, EF2, EF3, EF4, EF5, EF25
#     persnr: EF1 to EF5
#     hh: EF1 to EF4
#	  famnr: EF1 to EF4 + EF25

Daten$persnr <- as.numeric(Daten$EF1)*10000000000 + as.numeric(Daten$EF2)*1000000000 + as.numeric(Daten$EF3)*100000 + as.numeric(Daten$EF4)*1000 + as.numeric(Daten$EF5)*10
Daten$hhnr <- as.numeric(Daten$EF1)*10000000000 + as.numeric(Daten$EF2)*1000000000 + as.numeric(Daten$EF3)*100000 + as.numeric(Daten$EF4)*1000 + 1
Daten$famnr <- as.numeric(Daten$EF1)*10000000000 + as.numeric(Daten$EF2)*1000000000 + as.numeric(Daten$EF3)*100000 + as.numeric(Daten$EF4)*1000 + as.numeric(Daten$EF25)*1

# Alternative using pipes

Daten <- Daten %>%
  mutate(persnr = as.numeric(Daten$EF1)*10000000000 + as.numeric(Daten$EF2)*1000000000 + as.numeric(Daten$EF3)*100000 + as.numeric(Daten$EF4)*1000 + as.numeric(Daten$EF5)*10,
         hhnr = as.numeric(Daten$EF1)*10000000000 + as.numeric(Daten$EF2)*1000000000 + as.numeric(Daten$EF3)*100000 + as.numeric(Daten$EF4)*1000 + 1,
         as.numeric(Daten$EF1)*10000000000 + as.numeric(Daten$EF2)*1000000000 + as.numeric(Daten$EF3)*100000 + as.numeric(Daten$EF4)*1000 + as.numeric(Daten$EF25)*1)


# d.  Preparation for test: number of household unequal number of family
#     If: number of family (famnr) unequal number of household (hhnr), then: difference number of household (hhnr) - number of family (nrdiff) equals 1

Daten$nrdiff <- 0
Daten$nrdiff[Daten$famnr!= Daten$hhnr] <- 1

# Alternative using pipes

Daten <- Daten %>%
  mutate(nrdiff = ifelse(Daten$famnr!= Daten$hhnr, 1, 0))


# e.  Preparation test: multiple number of person
#     If number of person (persnr) equal predecessor then test unique number of person (piddiff) equals 1  

Daten <- Daten[order(Daten$persnr),]
Daten$piddiff <- 0
Daten$piddiff[Daten$persnr == lag(Daten$persnr,1)] <- 1

# Alternative using pipes

Daten <- Daten %>%
  arrange(persnr) %>%
  mutate(piddiff = case_when(Daten$persnr == lag(Daten$persnr,1) ~ 1, Daten$persnr != lag(Daten$persnr,1) ~ 0, NA ~ 0)) # first observation NA


# f. Labeling variables and values (The command label from the Hmisc package can be used).

label(Daten$marr) <- "Married"

label(Daten$hhnr) <- "Number of household"
label (Daten$famnr) <- "Number of family"
label(Daten$persnr) <-	"Number of person"

label(Daten$piddiff) <- "Test unique number of person"
label(Daten$nrdiff) <- "Difference number of household - number of family"

levels(Daten$marr)[1] <- "yes" 
levels(Daten$marr)[0] <- "no"

levels(Daten$nrdiff)[1] <- "Number of household and number of family different"
levels(Daten$nrdiff)[0] <- "Number of household and number of family identical"

levels(Daten$piddiff)[1] <- "Number of person multiple"
levels(Daten$piddiff)[0] <- "Number of person unique"


# g. Create a new dataset by filtering for marr = 1

Daten_marr <- Daten[which(Daten$marr==1),]
# or:
Daten_marr <- subset(Daten, Daten$marr==1)
# or:
Daten_marr <- Daten %>%
  filter(marr == 1)


# h. Create a new temporary work dataset by filtering for marr = 1 (To be deleted if it is no longer needed after the analysis!)

# as csv:
write.table(Daten, paste0(neudatenpfad,"Temp2.csv"), sep=";")
# or in the more efficient R-data format:
save(Daten, file=paste0(neudatenpfad,"Temp2.rdata"))


#	-------------------------------------------------------------------------------------------------------------------
# 2. Data analyses
# -------------------------------------------------------------------------------------------------------------------

# For every generated result it has to be stated if it is to be checked for confidentiality or if it is generated 
# solely for the purpose of the RDC output checking process. This declaration can be made as a general comment 
# such as "All produced results are needed." or "Only weighted results are needed.", as long as the wording is 
# unambiguous.

# Note for the RDC: the results generated under point 2 are not to be released.


# Data analyses full dataset:

# Output no. 2.1: Number of household unequal to number of family

table(Daten$nrdiff)


# Output no. 2.2: Test multiple number of person

table(Daten$piddiff)


# Data analyses by variable marr using the dataset Daten_marr:

# Output no. 2.3: Number of household unequal number of family
table(Daten_marr$nrdiff)


# Output no. 2.4: Test multiple number of person
table(Daten_marr$piddiff)


#	-------------------------------------------------------------------------------------------------------------------
#	3. Weighted analyses
#	-------------------------------------------------------------------------------------------------------------------

# It is necessary for the check for confidentiality to always add the unweighted results when weighted 
# results are generated (see brochure 2.7 Output of the underlying numbers of cases and marking of the relations).


# Output no. 3.1: unweighted frequency of the federal state

table(Daten$EF1)
# or:
kable(table(Daten$EF1))


# Output no. 3.2: weighted frequency of the federal state

wtd.table(Daten$EF1, weights=as.numeric(Daten$EF952))


# Output no. 3.3: unweighted regression using the dependent variable age (EF44) and the independent variables 
# sex (EF46) and married (marr)

summary(lm(Daten$EF44 ~ Daten$EF46 + Daten$marr, Daten))


# Output no. 3.4: unweighted regression using the dependent variable age (EF44) and the independent variables 
# sex (EF46) and married (marr)

summary(lm(Daten$EF44 ~ Daten$EF46 + Daten$marr, Daten ,weights=(as.numeric(Daten$EF952))))                


#	-------------------------------------------------------------------------------------------------------------------
#	4. 4. Analyses using filter conditions
#	-------------------------------------------------------------------------------------------------------------------

# Remaining samples that represent the difference to the "total" value are to be avoided.
# Example: You generate a table "total" and a table "male".
# The remaining sample/difference is "female". It has to be generated as well (see brochure 2.9 Output of 
# difference groups and marking of relations and 3.2.4 Analysis of subgroups).


# Output no. 4.1: Frequency of the highest qualification by total

table(Daten$EF310)
# or:
kable(table(Daten$EF310))


# Output no. 4.2: Frequency of the highest qualification by male

table(Daten$EF310[Daten$EF46 == 1])


# Output no. 4.3: Frequency of the highest qualification by female

table(Daten$EF310[Daten$EF46 == 2]) 

# Note: Alternatively, a cross table without a previous case selection can be used for this kind of analysis. 
# By generating a cross table, remaining samples are avoided directly.


#	-------------------------------------------------------------------------------------------------------------------
#	5. Output of descriptive coefficients
#	-------------------------------------------------------------------------------------------------------------------

# For reasons of confidentiality, minima and maxima of metric variables are to be suppressed (see brochure 3.2.1
# Output of individual values). 


# Output no. 5.1: Number of cases, mean and standard deviation for age of all single persons (EF49==1)

# 1. variant: 

x <- Daten$EF44[Daten$EF49==1]
c(N=length(x),Mean=mean(x),Sd=sd(x))

# Alternative using pipes

table_single <- Daten %>%
  select(EF44, EF49) %>%
  filter(EF49 == 1) %>%
  group_by(EF49) %>%
  summarise(N = n(),
            Mean = mean(EF44),
            SD = sd(EF44))
kable(table_single)

# Output remaining subgroup!

x <- Daten$EF44[Daten$EF49!=1]
c(N=length(x),Mean=mean(x),Sd=sd(x))

# Alternative using pipes

table_not_single <- Daten %>%
  select(EF44, EF49) %>%
  filter(EF49 != 1) %>%
  group_by() %>%
  summarise(N = n(),
            Mean = mean(EF44),
            SD = sd(EF44))
kable(table_not_single)


# 2. variant: using the by-command to get descriptive results for all categories 
#	-------------------------------------------------------------------------------------------------------------------

by(Daten$EF44, Daten["EF49"], function(x){
  c(N=length(x), Mean=mean(x), SD=sd(x))
}) 

# Alternative using pipes

table_alter <- Daten %>%
  select(EF44, EF49) %>%
  group_by(EF49) %>%
  summarise(N = n(), 
            Mean = mean(EF44),
            SD = sd(EF44))
kable(table_alter)

# Note: For economic statistics, when generating descriptive coefficients the largest and next to largest value 
# and the sum of all values of the concerned variable (e.g. volume of sales, income) are to be stated (see brochure
# 3.1.3 Rules of dominance).

# Remove unneccesary tables

rm(table_single)
rm(table_not_single)


#	-------------------------------------------------------------------------------------------------------------------
#	6. Output of dummy variables 
#	-------------------------------------------------------------------------------------------------------------------

# In addition to the sum-command, a frequency table is to be produced because the number of cases is needed 
# for the check for confidentiality.


#	Output no. 6.1:  Number of cases, mean and standard deviation for sex of all persons aged older than 65 (EF44 > 65)

by(Daten$EF46, Daten["EF44"]>65, function(x){
  c(N=length(x),Mean=mean(x),SD=sd(x))
})

# Alternative using pipes

table_65 <- Daten %>%
  mutate(alter = case_when(EF44 <= 65 ~ 0, 
                           EF44 > 65 ~ 1)) %>%
  select(alter, EF46) %>%
  group_by(alter) %>%
  summarise(N = n(),
            Mean = mean(EF46), 
            SD = sd(EF46))
kable(table_65)


#	Output no. 6.2  Frequency table for sex of all persons aged older than 65 (EF44 > 65)

table(Daten$EF46[Daten$EF44>65])

#	Note for the RDC: only for the check for confidentiality

table(Daten$EF46[Daten$EF44<=65])


#	-------------------------------------------------------------------------------------------------------------------
#	7. Output of value table 
#	-------------------------------------------------------------------------------------------------------------------

# When generating value tables, the corresponding cases of numbers always have to be stated as well.


# Generation of a user-defined table with number of cases, mean and valid frequency (N) of age (EF44) by 
# class of marital status (EF49)

#	Output no. 7.1: Cross table age and marital status to output the valid frequency (N)

matrix(c(tapply(Daten$EF44, Daten$EF49, length), tapply(Daten$EF44, Daten$EF49, mean)), nrow=2, byrow=T,  dimnames=list (c("N", "Mean"), 1:7))

# Alternative using pipes (see line 392

kable(table_alter)


#	-------------------------------------------------------------------------------------------------------------------
#	----
#	----	Part III: Program closure
#	----
#	-------------------------------------------------------------------------------------------------------------------

#	delete temporary datasets

file.remove(paste0(neudatenpfad,"Temp1.rdata"))
file.remove(paste0(neudatenpfad,"Temp2.rdata"))
file.remove(paste0(neudatenpfad,"Temp2.csv"))

#	-------------------------------------------------------------------------------------------------------------------
#	N O T E:

# The sample program code at hand illustrates an example for an initial program code. If analyses are executed 
# in subsequent program codes and these analyses have a content-related connection to already generated results, 
# these connections are to be marked with a comment when processing the data and when the analysis is being
# commanded.
#	-------------------------------------------------------------------------------------------------------------------