************************************************************************************************************************;
*********************************************** Sample program code SAS ************************************************;
 
*** Note: The sample program code serves as an orientation for writing your program code. The objective is to        ***;
*** generate an output file that is helping the output check for confidentiality in the best possible way.           ***;
*** Please note: This sample program code does not provide statistic-specific support on the processing and          ***;
*** analysis of your requested data.                                                                                 ***;
                                                                                                                    
************************************************************************************************************************;


*** Compress datasets and alignment of the output; 
options nocenter linesize=256 pagesize=90 compress=yes;

*** Macros for paths;
%let datapath	=	<Path is added by the Research Data Centre>;
%let outputpath = 	<Path is added by the Research Data Centre>;

*** Macros for names of dataset and output;
%let dataname  = <dataname>;     			/*Insert name of the dataset*/
%let outputname = <outputname>; 			/*Insert name of the output*/

*** Assign libname;
libname data "&datapath";


************************************************************************************************************************;
*** Start record of the output file;
ods html body = "&outputpath./&outputname..html";


************************************************************************************************************************;
************************************************************************************************************************;
************************************************************************************************************************;


************************************************************************************************************************;
************************************************************************************************************************;
*** Project title:			<Women and employment in Germany>       
*** Data base:		 		<Microcensus 2012>
***
*** Name of program code:	<name_program_code.sas> 
*** created: 				<Date> 
*** by: 					<Name> 
*** E-mail: 				<E-mail-address> 
*** Phone: 					<phone number> 
*** 
*** Name of output file: 	<outputname.html>
*** 
*** 
*** Outline of the program: 
***			<Program code for the examination of multiple person data sets (Check of the data base), 
***			 descriptive analyses> 
*** 
***
*** Used variables: 
*** Original variables: 
***    <EF1:   		Federal state 
*** 	EF2:   		Administrative district 
*** 	EF3S:  		Number of selected district 
*** 	EF4S:  		Serial number of household in selected district 
*** 	EF5S:  		Serial number of person in the household
*** 	EF25:  		Serial number of familiy in the household
*** 	EF30:  		Population at primary residence
*** 	EF31:  		Population in private households
*** 	EF44:  		Age
*** 	EF46:  		Sex
*** 	EF49:  		Marital status
*** 	EF310: 		Highest qualification
*** 	EF952: 		Standard projection factor year>
***
*** 
*** Variables newly created in this program code <name_program_code.sas>: 
***    <marr:       dichotomous variable married yes/no
***     persnr:  	Number of person
*** 	famnr:   	Number of familiy 
*** 	hhnr:    	Number of household 
*** 	nrdiff:  	Difference number of household - number of family
*** 	piddiff: 	Test unique number of person>
***
*** Note: If you use variables that were created in a previous program code, please list them in a separate block. 
***
*** Variable projection factor: EF952
***
***
************************************************************************************************************************;
************************************************************************************************************************;


************************************************************************************************************************;
*** I. Data processing
************************************************************************************************************************;


*** a. Define formats;

proc format;
    value marrlab       1 = 'yes'
	                    0 = 'no';

	value nrdifflab 	1 = 'Number of household and number of family different'
				 		0 = 'Number of household and number of family identical';

	value piddifflab 	1 = 'Number of person multiple' 
						0 = 'Number of person unique';
run;


*** b. Input dataset;
*** Direct selection of necessary variables (memory space- and runtime-efficient);

data work.workfile;                                          
	set daten.&dataname
	(keep = EF1 EF2 EF3S EF4S EF5S EF25 EF30 EF31 EF44 EF46 EF49 EF310 EF952

/* Population in private households (EF31 = 1) at the place of permanent residence (EF30 < 3)*/

	where = ((EF31 = 1) & (EF30 < 3)) );


*** c. Generation dichotomous variable marr which shows if a person is married; 

    marr = 0;
    if EF49 = 2 then marr = 1;
	

*** d. Generation number of household and family from EF1, EF2, EF3S, EF4S, EF5S, EF25
*** persnr EF1-EF5S
*** hhnr EF1-EF4S
*** famnr EF1-EF4S + EF25;

	persnr = (EF1*10000000000) + (EF2*1000000000) + (EF3S*100000) + (EF4S*1000) + (EF5S*10);
	hhnr = (EF1*10000000000) + (EF2*1000000000) + (EF3S*100000)+(EF4S*1000) + 1;
	famnr = (EF1*10000000000) + (EF2*1000000000) + (EF3S*100000) + (EF4S*1000) + (EF25*1);


*** e. Preparation test: number of household different from number of family;
*** If number of family (famnr) is different then number of household (hhnr)   
*** then difference number of household (hhnr) - number of family (nrdiff) equals 1;

	nrdiff=0;
	if (famnr ~= hhnr) then nrdiff = 1;
run;


*** f. Preparation test: multiple number of person
*** If number of person (persnr) equals that of the predecessor
*** then test unique number of person (piddiff) equals 1;

proc sort data = work.workfile;
	by persnr;
run;

data work.workfile;
	set work.workfile;
	piddiff = 0; 
	if persnr = LAG(persnr) then piddiff = 1;


*** g. Labeling of variables and values;

	label 		
                marr     = 'Married'
				hhnr 	 = 'Number of household' 
				famnr 	 = 'Number of family' 
				persnr	 = 'Number of person'
				nrdiff	 = 'Difference number of household - number of family' 
		  		piddiff	 = 'Test unique number of person';

    format 		
				marr marrlab. 
	       		nrdiff nrdifflab.
	       		piddiff piddifflab.;
run;



************************************************************************************************************************;
*** II. Data analysis
************************************************************************************************************************;

*** For every produced result it has to be stated if it is to be checked for confidentiality or if it is produced 
*** solely for the purpose of the RDC output checking process. This declaration can be made as a general comment 
*** like "All produced results are needed." or "Only weighted results are needed.", as long as the wording is 
*** unambiguous.

*** Output No. 1: Number of household different from number of family;

proc freq data = work.workfile;
	title 'Output No. 1: Number of household different from number of family';
	table nrdiff;	
run;


*** Output No. 2: Test multiple number of person;
	
proc freq data = work.workfile;
	title 'Output No. 2: Test multiple number of person';
	table piddiff;	
run;


************************************************************************************************************************;
*** a. Weighted analyses ***

*** It is necessary for the check for confidentiality to always add the unweighted results when weighted
*** results are generated.

*** Output No. 3a: Unweighted frequencies for the federal state;

proc freq data = work.workfile;
	title 'Output No. 3a: Unweighted frequencies for the federal state';
	table EF1;	
run;


*** Output No. 3b: Weighted frequencies for the federal state;

proc freq data = work.workfile;
    weight EF952;
	title 'Output No. 3b: Weighted frequencies for the federal state';
	table EF1;	
run;


*** Output No. 4a: Unweighted regression using the dependent variable age (EF44) and
***                the dependend variables sex (EF46) and married (marr);

title 'Unweighted regression using the dependent variable age (Ef44) and the depentend variables 
sex (EF46) and married (marr)';
proc reg data = work.workfile;
	model EF44 = EF46 marr;
run;


*** Output No. 4b: Weighted regression using the dependent variable age (EF44) and
***                the dependend variables sex (EF46) and married (marr);

title 'Weighted regression using the dependent variable age (EF44) and the depentend variables 
sex (EF46) and married (marr)';
proc reg data = work.workfile;
  	weight EF952;
  	model EF44 = EF46 marr;
run;


************************************************************************************************************************;
*** b. Analyses using filter conditions ***

*** Remaining samples that contain the difference to the "total" value are to be avoided.
*** Example: You generate a "total" table and a "male" table.
*** The remaining sample/difference is "female". It has to be generated as well.

*** Output No. 5a-c: Frequency of the highest qualification by total/male/female;

proc freq data = work.workfile;
	title 'Output No. 5a: Frequency of the highest qualification by total';
	table EF310;
run;

proc freq data=work.workfile;
	title 'Output No. 5b: Frequency of the highest qualification by male';
	table EF310;
	where EF46 = 1;
run;

proc freq data = work.workfile;
	title 'Output No. 5c: Frequency of the highest qualification by female';
	table EF310;
	where EF46 = 2;
run;


*** Note: Alternatively, a cross table without a previous case selection can be used for this kind of analysis.
*** By generating a cross table, remaining samples are avoided.

	
************************************************************************************************************************;
*** c. Output of descriptive coefficients ***

*** For reasons of confidentiality, minima and maxima of metric variables are to be suppressed.

*** Output No. 6: Number of cases, mean and standard deviation for age of all single persons (EF49=1);

title 'Output No. 6: Number of cases, mean and standard deviation for age of all single persons (EF49=1)';
proc means data = work.workfile n mean std;
	var EF44;
	where EF49 = 1;
run;

*** Note: For economic statistics, when generating descriptive coefficients the largest and next to largest value and the sum of all
*** values of the concerned variable (e.g. volume of sales, income) are to be stated. They are needed for the check for confidentiality.

************************************************************************************************************************;
*** d. Output of dummy variables ***

*** In addition to the proc-means-command, a frequency table is to be produced because the number of cases is needed
*** for the check for confidentiality.
 
*** Output No. 7a-b: Number of cases, mean and standard deviation for sex of all persons aged older than 65 (EF44 > 65);

title 'Output No. 7a: Number of cases, mean and standard deviation for sex of all persons aged older than 65 (EF44 > 65)';
proc means data = work.workfile n mean std;
	var EF46;
	where EF44 > 65;
run;

title 'Output No. 7b: Frequency table of sex of all persons aged older than 65 (EF44 > 65)';
proc freq data = work.workfile;
	tables EF46;
	where EF44 > 65;
run;


************************************************************************************************************************;
*** e. Output of value tables ***

*** When generating value tables, the corresponding cases of numbers always have to be stated as well.

*** Generation of a user-defined table with number of cases, mean and valid frequency (N) of age (EF44) by
*** class of marital status (EF49).

*** Output No. 8: Cross table age and marital status;

proc tabulate data = work.workfile;
	title 'Output No. 8: Cross table age and marital status';
	var EF44;
	class EF49; 
	table EF44 * (mean N), EF49;
run;


************************************************************************************************************************;

*** The sample program code at hand illustrates an example for an initial program code. If analyses are executed in  
*** subsequent program codes and these analyses have a content-related connection to already generates results, these  
*** connections are to be marked with a comment when processing the data and when the analysis is being commanded.



************************************************************************************************************************;
*** III. Deletion of all temporary files as soon as they aren't needed anymore;
************************************************************************************************************************;

proc datasets library = work nolist;
    delete workfile;
run;

************************************************************************************************************************;

ods html close;
