******************************************************************************************************************************.
********************************************* Sample program code SPSS ********************************************** .
                               
*** Note: The sample program code serves as an orientation for writing your program code. The objective     ***.
*** is to generate an output file that is helping the output check for confidentiality in the best possible way.  ***.
*** Please note: This sample program code does not provide statistic-specific support on the processing     ***.
*** and analysis of your requested data.                                                                                                  ***.
                                                                                                                    
*******************************************************************************************************************************.

*** Macros for paths.
DEFINE !DATAPATH   () '<Path is added by the Research Data Centre>\' !ENDDEFINE.
DEFINE !OUTPUTPATH () '<Path is added by the Research Data Centre>\' !ENDDEFINE.

*** Makros fr Datei- und Outputnamen.
*** Dateiname und Outputname einfgen.
DEFINE !DATANAME    () '<dataname.sav>' !ENDDEFINE.  
DEFINE !OUTPUTNAME () '<outputname>'    !ENDDEFINE. 


*******************************************************************************************************************.
*** Start record of the output file.
OUTPUT NEW.


*******************************************************************************************************************.
*******************************************************************************************************************.
*******************************************************************************************************************.


*******************************************************************************************************************.
*******************************************************************************************************************.
*** Project title:			<Women and employment in Germany>       
*** Data base:		 		<Microcensus 2012>
***
*** Name of program code:	<name_program_code.sps> 
*** created: 				<Date> 
*** by: 					<Name> 
*** E-mail: 				<E-mail-address> 
*** Phone: 					<phone number> 
*** 
*** Name of output file: 	<outputname.spv>
*** 
*** 
*** Outline of the program: 
***			<Program code for the examination of multiple person data sets (Check of the data base), 
***			 descriptive analyses> 
*** 
***
*** Used variables: 
*** Original variables: 
***    <EF1:   		Federal state 
*** 	EF2:   		Administrative district 
*** 	EF3S:  		Number of selected district 
*** 	EF4S:  		Serial number of household in selected district 
*** 	EF5S:  		Serial number of person in the household
*** 	EF25:  		Serial number of familiy in the household
*** 	EF30:  		Population at primary residence
*** 	EF31:  		Population in private households
*** 	EF44:  		Age
*** 	EF46:  		Sex
*** 	EF49:  		Marital status
*** 	EF310: 		Highest qualification
*** 	EF952: 		Standard projection factor year>
***
*** 
*** Variables newly created in this program code <name_program_code.sps>: 
***    <marr:       dichotomous variable married yes/no
***     persnr:  	Number of person
*** 	famnr:   	Number of familiy 
*** 	hhnr:    	Number of household 
*** 	nrdiff:  	Difference number of household - number of family
*** 	piddiff: 	Test unique number of person>
***
*** Note: If you use variables that were created in a previous program code, please list them in a separate block. 
***
*** Variable projection factor: EF952
***         
***                                                                     
*******************************************************************************************************************.
*******************************************************************************************************************.                                                            



*******************************************************************************************************************.
*** I. Data processing
*******************************************************************************************************************.


*** a. Input dataset.
*** Direct selection of necessary variables (memory space- and runtime-efficient).

GET FILE = !DATAPATH+!DATANAME
/KEEP = EF1 EF2 EF3S EF4S EF5S EF25 EF30 EF31 EF44 EF46 EF49 EF310 EF952.  
EXECUTE.

*** Population in private households (EF31 = 1) at the place of permanent residence (EF30 < 3).

SELECT IF (EF31 = 1) & (EF30 < 3).
EXECUTE.


*** b. Generation dichotomous variable marr which shows if a person is married.

RECODE EF49 (2 = 1) (1,3,4,5,6,7 = 0) INTO marr.


*** c. Generation number of household and family from EF1, EF2, EF3S, EF4S, EF5S, EF25.
*** persnr: EF1-EF5S
*** hhnr:    EF1-EF4S
*** famnr:  EF1-EF4S + EF25.

COMPUTE persnr = (EF1*10000000000) + (EF2*1000000000) + (EF3S*100000) + (EF4S*1000) + (EF5S*10).
COMPUTE hhnr = (EF1*10000000000) + (EF2*1000000000) + (EF3S*100000) + (EF4S*1000) + 1.
COMPUTE famnr = (EF1*10000000000) + (EF2*1000000000) + (EF3S*100000) + (EF4S*1000) + (EF25*1). 
EXECUTE.


*** d. Preparation test: number of household different from number of family.
*** If number of family (famnr) is different then number of household (hhnr)
*** then difference number of household (hhnr) - number of family (nrdiff) equals 1.

COMPUTE nrdiff = 0.
EXECUTE.
DO IF famnr ~= hhnr.
 COMPUTE nrdiff = 1.
END IF.


*** e. Preparation test: multiple number of person.
*** If number of person (persnr) equals that of the predecessor
*** then test unique number of person (piddiff) equals 1.

SORT CASES BY persnr.
EXECUTE.
IF persnr EQ LAG(persnr) piddiff = 1.
EXECUTE.


*** f. Labeling of variables and values.

VARIABLE LABELS   marr          'Married'
                                 hhnr          'Number of household'
                                 famnr        'Number of family'
                                 persnr       'Number of person'
                                 nrdiff         'Difference number of household - number of family'
                                 piddiff        'Test unique number of person'.

VALUE LABELS         marr        1 'yes'
                                                0 'no'.
VALUE LABELS         nrdiff        1 'Number of household and number of family different'
	                                               0 'Number of household and number of family identical'. 	
VALUE LABELS        piddiff       1 'Number of person multiple'
	                                               0 'Number of person unique'. 



*******************************************************************************************************************.
*** II. Data analysis
*******************************************************************************************************************.

*** For every produced result it has to be stated if it is to be checked for confidentiality or if it is produced 
*** solely for the purpose of the RDC output checking process. This declaration can be made as a general comment 
*** like "All produced results are needed." or "Only weighted results are needed.", as long as the wording is 
*** unambiguous.

*** Output No. 1: Number of household different from number of family.

TITLE "Output No. 1: Number of household different from number of family".
FREQUENCIES VAR = nrdiff.


*** Output No. 2: Test multiple number of person.

TITLE "Output No. 2: Test multiple number of person".	
FREQUENCIES VAR = piddiff.


*******************************************************************************************************************.
*** a. Weighted analyses ***

*** It is necessary for the check for confidentiality to always add the unweighted results 
*** when weighted results are generated.

*** Output No. 3a: Unweighted frequencies for the federal state.

TITLE "Output No. 3a: Unweighted frequencies for the federal state".	
FREQUENCIES VAR = EF1.


*** Output No. 3b: Weighted frequencies for the federal state.

WEIGHT BY EF952.
TITLE "Output No. 3b: Weighted frequencies for the federal state".	
FREQUENCIES VAR = EF1.
WEIGHT OFF.


*** Output No. 4a: Unweighted regression using the dependent variable age (EF44) and
***                        the dependend variables sex (EF46) and married (marr).

REGRESSION VARIABLES EF46 marr
/DEPENDENT = EF44
/METHOD = STEPWISE.


*** Output No. 4b: Weighted regression using the dependent variable age (EF44) and
***                        the dependend variables sex (EF46) and married (marr).

WEIGHT BY EF952.
REGRESSION VARIABLES EF46 marr
/DEPENDENT = EF44
/METHOD = STEPWISE.
WEIGHT OFF.


*******************************************************************************************************************.
*** b. Analyses using filter conditions ***

*** Remaining samples that contain the difference to the "total" value are to be avoided.
*** Example: You generate a "total" table and a "male" table.
*** The remaining sample/difference is "female". It has to be generated as well.

*** Output No. 5a-c: Frequency of the highest qualification by total/male/female. 

TITLE "Output No. 5a: Frequency of the highest qualification by total".
FREQUENCIES VAR = EF310.
EXECUTE.

TITLE "Output No. 5b: Frequency of the highest qualification by male".
TEMPORARY. 
SELECT IF EF46 = 1.
FREQUENCIES VAR = EF310.
EXECUTE.

TITLE "Output No. 5c: Frequency of the highest qualification by female".
TEMPORARY. 
SELECT IF EF46 = 2.
FREQUENCIES VAR = EF310.
EXECUTE.


*** Note: Alternatively, a cross table without a previous case selection can be used for this kind of analysis.
*** By generating a cross table, remaining samples are avoided.


*******************************************************************************************************************.
*** c. Output of descriptive coefficients ***

*** For reasons of confidentiality, minima and maxima of metric variables are to be suppressed.

*** Output No. 6: Number of cases, mean and standard deviation for age of all single persons (EF49=1).

TITLE "Output No. 6: Number of cases, mean and standard deviation for age of all single persons (EF49=1)".
TEMPORARY.
SELECT IF EF49 = 1.
SUMMARIZE EF44 /CELLS = count mean stddev.


*** Note: For economic statistics, when generating descriptive coefficients the largest and next to largest value 
*** and the sum of all values of the concerned variable (e.g. volume of sales, income) are to be stated. They are 
*** needed for the check for confidentiality.


*******************************************************************************************************************.
*** d. Output of dummy variables ***

*** In addition to the proc-means-command, a frequency table is to be produced because the number of cases 
*** is needed for the check for confidentiality.
 
*** Output No. 7a-b: Number of cases, mean and standard deviation for sex of all persons aged older than 65 (EF44 > 65);

TITLE "Output No. 7a: Number of cases, mean and standard deviation for sex of all persons aged older than 65 (EF44 > 65)".
TEMPORARY.
SELECT IF EF44 > 65.
SUMMARIZE EF46  /CELLS= count mean stddev.

TITLE "Output No. 7b: Frequency table of sex of all persons aged older than 65 (EF44 > 65)".
TEMPORARY.
SELECT IF EF44 > 65.
FREQUENCIES VAR = EF46.


*******************************************************************************************************************.
*** e. Output of value tables ***

*** When generating value tables, the corresponding cases of numbers always have to be stated as well.

*** Generation of a user-defined table with number of cases, mean and valid frequency (N) of age (EF44) by
*** class of marital status (EF49)

*** Output No. 8: Cross table age and marital status.

CTABLES
  /VLABELS VARIABLES=EF49 EF44 DISPLAY = DEFAULT
  /TABLE EF44 [MEAN, VALIDN F40.0] BY EF49
  /CATEGORIES VARIABLES = EF49 ORDER = A KEY = VALUE EMPTY = EXCLUDE
  /TITLES
   TITLE = 'Output No. 8: Cross table age and marital status'.


*******************************************************************************************************************.

*** The sample program code at hand illustrates an example for an initial program code. If analyses are  
*** executed in subsequent program codes and these analyses have a content-related connection to   
*** already generates results, these connections are to be marked with a comment when processing 
*** the data and when the analysis is being commanded.



*******************************************************************************************************************.
*** III. Saving the output dataset as spv- and xls-document.
*******************************************************************************************************************.

OUTPUT SAVE OUTFILE = !OUTPUTPATH+!OUTPUTNAME+".spv".  

OUTPUT EXPORT
 /CONTENTS EXPORT = VISIBLE
 /XLS DOCUMENTFILE = !OUTPUTPATH+!OUTPUTNAME
 OPERATION = CREATEFILE
 SHEET = 'Tabelle1'.








